@@ -4,10 +4,12 @@ import pytest
 from py.path import local
 from pytest import CaptureFixture
 
+from sybil import Sybil
+from sybil.parsers.rest import PythonCodeBlockParser, DocTestParser
 from sybil.python import import_cleanup
 from .helpers import (
     run_pytest, run_unittest, PYTEST, run, write_config, UNITTEST, write_doctest,
-    functional_sample, clone_functional_sample
+    functional_sample, clone_functional_sample, skip_if_37_or_older, check_path, sample_path
 )
 
 
@@ -272,7 +274,7 @@ def test_filter_multiple_patterns(tmpdir: local, capsys: CaptureFixture[str], ru
 def test_skips(tmpdir: local, capsys: CaptureFixture[str], runner: str):
     root = clone_functional_sample('skips', tmpdir)
     write_config(root, runner,
-                 parsers="[PythonCodeBlockParser(), skip, DocTestParser()]",
+                 parsers="[PythonCodeBlockParser(), SkipParser(), DocTestParser()]",
                  patterns="['*.rst']")
     results = run(capsys, runner, root)
     assert results.total == 10, results.out.text
@@ -331,6 +333,7 @@ def test_modules_not_importable_unittest(tmpdir: local, capsys: CaptureFixture[s
     out.then_find("ModuleNotFoundError: No module named 'b'")
 
 
+@skip_if_37_or_older()
 @pytest.mark.parametrize('runner', [PYTEST, UNITTEST])
 def test_package_and_docs(tmpdir: local, capsys: CaptureFixture[str], runner: str):
     root = clone_functional_sample('package_and_docs', tmpdir)
@@ -346,3 +349,90 @@ def test_package_and_docs(tmpdir: local, capsys: CaptureFixture[str], runner: st
     results.out.then_find('good')
     results.out.then_find('Got:')
     results.out.then_find('bad')
+
+
+@pytest.mark.parametrize('runner', [PYTEST, UNITTEST])
+def test_multiple_sybils_process_all(tmpdir: local, capsys: CaptureFixture[str], runner: str):
+    write_doctest(tmpdir, 'test.rst')
+    write_doctest(tmpdir, 'test.txt')
+    config_template = """
+    from sybil.parsers.rest import DocTestParser
+    from sybil import Sybil
+    
+    sybil1 = Sybil(parsers=[DocTestParser()], pattern='test.*')
+    sybil2 = Sybil(parsers=[DocTestParser()], pattern='test.*')
+    
+    {assigned_name} = (sybil1 + sybil2).{integration}()
+    """
+    write_config(tmpdir, runner, template=config_template)
+    results = run(capsys, runner, tmpdir)
+    if runner == PYTEST:
+        # the pytest integration only looks at each file once
+        expected_total = 2
+    else:
+        expected_total = 4
+    assert results.total == expected_total, results.out.text
+
+
+@pytest.mark.parametrize('runner', [PYTEST, UNITTEST])
+def test_multiple_sybils_process_one_each(tmpdir: local, capsys: CaptureFixture[str], runner: str):
+    write_doctest(tmpdir, 'test.rst')
+    write_doctest(tmpdir, 'test.txt')
+    config_template = """
+    from sybil.parsers.rest import DocTestParser
+    from sybil import Sybil
+
+    rst = Sybil(parsers=[DocTestParser()], pattern='*.rst')
+    txt = Sybil(parsers=[DocTestParser()], pattern='*.txt')
+
+    {assigned_name} = (rst + txt).{integration}()
+    """
+    write_config(tmpdir, runner, template=config_template)
+    results = run(capsys, runner, tmpdir)
+    assert results.total == 2, results.out.text
+
+
+@pytest.mark.parametrize('runner', [PYTEST, UNITTEST])
+def test_myst(capsys: CaptureFixture[str], runner: str):
+    results = run(capsys, runner, functional_sample('myst'))
+    out = results.out
+
+    # Check all the tests are found:
+    out.assert_has_run(runner, '/doctest.md', line=7)
+    out.assert_has_run(runner, '/doctest.md', line=14)
+    out.assert_has_run(runner, '/doctest.md', line=25)
+    out.assert_has_run(runner, '/doctest.md', line=31)
+    out.assert_has_run(runner, '/python.md', line=5)
+    out.assert_has_run(runner, '/python.md', line=11)
+    out.assert_has_run(runner, '/python.md', line=17)
+    out.assert_has_run(runner, '/python.md', line=26)
+    out.assert_has_run(runner, '/python.md', line=41)
+    out.assert_has_run(runner, '/python.md', line=47)
+    out.assert_has_run(runner, '/python.md', line=49)
+
+    # unittest treats exceptions as errors rather than failures,
+    # and they appear at the top of the output, hence the conditionals below.
+
+    # Check counts:
+    assert results.total == 4+7, results.out.text
+    if runner == PYTEST:
+        assert results.failures == 2 + 1, results.out.text
+        assert results.errors == 0, results.out.text
+    else:
+        assert results.failures == 2 + 0, results.out.text
+        assert results.errors == 1, results.out.text
+
+    # Check error text:
+    if runner == UNITTEST:
+        out.then_find("Exception: boom!")
+    out.then_find("doctest.md, line 25, column 1 did not evaluate as expected:")
+    out.then_find("Expected:\n    3\nGot:\n    2\n")
+    out.then_find("doctest.md, line 31, column 1 did not evaluate as expected:")
+    out.then_find("Expected:\n    4\nGot:\n    2\n")
+    if runner == PYTEST:
+        out.then_find("Exception: boom!")
+
+@skip_if_37_or_older()
+def test_codeblock_with_protocol_then_doctest():
+    sybil = Sybil([PythonCodeBlockParser(), DocTestParser()])
+    check_path(sample_path('protocol-typing.rst'), sybil, expected=3)
