@@ -1,6 +1,5 @@
 from __future__ import print_function
 
-import os
 import re
 from functools import partial
 from os.path import split
@@ -10,7 +9,7 @@ import pytest
 from py.path import local
 
 from sybil import Sybil, Region
-from sybil.document import Document
+from sybil.document import Document, PythonDocument
 from sybil.example import Example, SybilFailure
 
 from .helpers import sample_path, write_doctest
@@ -133,6 +132,32 @@ class TestDocument:
             ' from line 1, column 2 to line 1, column 4'
         )
 
+    def test_add_at_same_place(self, document):
+        region1 = Region(0, 2, None, None)
+        region2 = Region(0, 3, None, None)
+        document.add(region1)
+        with pytest.raises(ValueError) as excinfo:
+            document.add(region2)
+        assert str(excinfo.value) == (
+            '<Region start=0 end=3 None>'
+            ' from line 1, column 1 to line 1, column 4 overlaps '
+            '<Region start=0 end=2 None>'
+            ' from line 1, column 1 to line 1, column 3'
+        )
+
+    def test_add_identical(self, document):
+        region1 = Region(0, 2, None, None)
+        region2 = Region(0, 2, None, None)
+        document.add(region1)
+        with pytest.raises(ValueError) as excinfo:
+            document.add(region2)
+        assert str(excinfo.value) == (
+            '<Region start=0 end=2 None>'
+            ' from line 1, column 1 to line 1, column 3 overlaps '
+            '<Region start=0 end=2 None>'
+            ' from line 1, column 1 to line 1, column 3'
+        )
+
     def test_add_overlaps_with_next(self, document):
         region1 = Region(0, 1, None, None)
         region2 = Region(1, 3, None, None)
@@ -227,6 +252,37 @@ class TestSybil:
         document = sybil.parse(write_doctest(tmpdir, 'test.rst'))
         assert type(document) is Document
 
+    def test_override_document_mapping(self):
+        sybil = Sybil([parse_for_x, parse_for_y], document_types={'.py': PythonDocument})
+        document = sybil.parse(Path(sample_path('sample1.txt')))
+        assert (evaluate_examples(document) ==
+                ['X count was 4, as expected',
+                 'Y count was 3, as expected'])
+        document = sybil.parse(Path(sample_path('comments.py')))
+        assert (evaluate_examples(document) ==
+                ['X count was 4, as expected',
+                 'Y count was 3, as expected'])
+
+    def test_addition(self):
+        rest = Sybil([parse_for_x])
+        myst = Sybil([parse_for_y])
+        sybil = rest + myst
+        assert sybil == [rest, myst]
+        # check integrations exist:
+        assert sybil.pytest
+        assert sybil.unittest
+
+    def test_addition_to_collection(self):
+        rest = Sybil([parse_for_x])
+        myst = Sybil([parse_for_y])
+        bust = Sybil([parse_for_y])
+        sybil = rest + myst
+        sybil += [bust]
+        assert sybil == [rest, myst, bust]
+        # check integrations exist:
+        assert sybil.pytest
+        assert sybil.unittest
+
 
 def check_into_namespace(example):
     parsed, namespace = example.region.parsed, example.namespace
